==> haskell-hasql-implicits-0.1.0.5-261-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-implicits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-implicits
version:              0.1.0.5
visibility:           public
id:                   hasql-implicits-0.1.0.5-J2ZryYJpU3a4wVPWgwrvD8
key:                  hasql-implicits-0.1.0.5-J2ZryYJpU3a4wVPWgwrvD8
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-implicits
synopsis:
    Implicit definitions for Hasql, such as default codecs for standard types

abi:                  1d11ccd74532c14b79dff57f6a0f5a09
exposed:              True
exposed-modules:      Hasql.Implicits.Encoders
hidden-modules:       Hasql.Implicits.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-implicits
hs-libraries:         HShasql-implicits-0.1.0.5-J2ZryYJpU3a4wVPWgwrvD8
depends:
    aeson-2.1.2.1-JD8QPsoBF4NC1qVY6ch6us base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    hasql-1.5.0.5-Hu0Rd0XRc0Y8AIDMPNecQe
    network-ip-0.3.0.3-96ScYtzCNHxE9ASYSUKw7j
    scientific-0.3.8.0-JrlaAXGfnydA9ZtLsuTElg text-2.0.2 time-1.12.2
    uuid-1.3.16-6LbWjn0qtVGBCyQuJNCPsW
    vector-0.13.2.0-L6HpF7nmtGm1K7R40olL6U

haddock-interfaces:
    /usr/share/doc/haskell-hasql-implicits/html/hasql-implicits.haddock

haddock-html:         /usr/share/doc/haskell-hasql-implicits/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-implicits-0.1.0.5-262-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-implicits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-implicits
version:              0.1.0.5
visibility:           public
id:                   hasql-implicits-0.1.0.5-8Vxoc8LvBacC6C2VBGHhct
key:                  hasql-implicits-0.1.0.5-8Vxoc8LvBacC6C2VBGHhct
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-implicits
synopsis:
    Implicit definitions for Hasql, such as default codecs for standard types

abi:                  35a3fbca0bf99725a95fad5f957f1ffd
exposed:              True
exposed-modules:      Hasql.Implicits.Encoders
hidden-modules:       Hasql.Implicits.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-implicits
hs-libraries:         HShasql-implicits-0.1.0.5-8Vxoc8LvBacC6C2VBGHhct
depends:
    aeson-2.1.2.1-H1ahbkp4Y7o4mfa4dlXJ2M base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    hasql-1.5.0.5-6rAplKwKOWEK6b3SC7utEJ
    network-ip-0.3.0.3-59IN4L0GEDDHlnKOcKgjwE
    scientific-0.3.8.0-6uPUyX2SLNQ5uEuI9iq9EK text-2.0.2 time-1.12.2
    uuid-1.3.16-DanzINKvYx15Ks0b7zIKaS
    vector-0.13.2.0-LTUcBi4LXgv7CSERMHHzQp

haddock-interfaces:
    /usr/share/doc/haskell-hasql-implicits/html/hasql-implicits.haddock

haddock-html:         /usr/share/doc/haskell-hasql-implicits/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
